@@ -1,22 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2007 by Ivan Vasić                                     *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Ivan Vasić <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "ipfilterwidget.h"
 
@@ -44,7 +29,7 @@ using namespace bt;
 
 namespace kt
 {
-IPFilterList *IPFilterWidget::filter_list = 0;
+IPFilterList *IPFilterWidget::filter_list = nullptr;
 
 IPFilterWidget::IPFilterWidget(QWidget *parent)
     : QDialog(parent)
@@ -102,7 +87,7 @@ void IPFilterWidget::add()
         QString ip = m_ip_to_add->text();
 
         if (!regex_match(ip.toStdString(), rx) || !filter_list->add(ip)) {
-            KMessageBox::sorry(this,
+            KMessageBox::error(this,
                                i18n("Invalid IP address <b>%1</b>. IP addresses must be in the format 'XXX.XXX.XXX.XXX'."
                                     "<br/><br/>You can also use wildcards like '127.0.0.*' or specify ranges like '200.10.10.0-200.10.10.40'.")
                                    .arg(ip));
@@ -110,7 +95,7 @@ void IPFilterWidget::add()
             return;
         }
     } catch (bt::Error &err) {
-        KMessageBox::sorry(this, err.toString());
+        KMessageBox::error(this, err.toString());
     }
 }
 
