@@ -27,7 +27,6 @@
 #include <KDBusService>
 #include <KLocalizedString>
 #include <KSharedConfig>
-#include <KStartupInfo>
 #include <KWindowSystem>
 #include <kwindowsystem_version.h>
 
@@ -175,7 +174,7 @@ int main(int argc, char **argv)
     about.setupCommandLine(&parser);
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("verbose"), i18n("Enable logging to standard output")));
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("silent"), i18n("Silently open torrent given on URL")));
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[URL]"), i18n("Document to open")));
+    parser.addPositionalArgument(QStringLiteral("+[URL]"), i18n("Document to open"));
     parser.process(app);
     about.processCommandLine(&parser);
 
@@ -245,7 +244,7 @@ int main(int argc, char **argv)
                 KWindowSystem::activateWindow(widget.windowHandle());
             }
         });
-        handleCmdLine(QStringList(), QString());
+        handleCmdLine(app.arguments(), QString());
 
         app.setQuitOnLastWindowClosed(false);
         app.exec();
