@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2007 by Joris Guisson and Ivan Vasic                    *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2007 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <QDBusConnection>
 #include <QFile>
@@ -186,7 +171,7 @@ QStringList DBus::groups() const
 bool DBus::addGroup(const QString &group)
 {
     kt::GroupManager *gman = core->getGroupManager();
-    return gman->newGroup(group) != 0;
+    return gman->newGroup(group) != nullptr;
 }
 
 bool DBus::removeGroup(const QString &group)
@@ -225,7 +210,7 @@ QObject *DBus::group(const QString &name)
             return group_map.find(i->second);
         i++;
     }
-    return 0;
+    return nullptr;
 }
 
 void DBus::log(const QString &line)
