@@ -1,22 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2010 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "jobtracker.h"
 #include "basicjobprogresswidget.h"
@@ -31,7 +16,7 @@ JobTracker::JobTracker(QObject *parent)
 
 JobTracker::~JobTracker()
 {
-    bt::Job::setJobTracker(0);
+    bt::Job::setJobTracker(nullptr);
 }
 
 void JobTracker::registerJob(KJob *job)
@@ -57,7 +42,7 @@ void JobTracker::unregisterJob(KJob *job)
 
 JobProgressWidget *JobTracker::createJobWidget(bt::Job *job)
 {
-    JobProgressWidget *p = new BasicJobProgressWidget(job, 0);
+    JobProgressWidget *p = new BasicJobProgressWidget(job, nullptr);
     widgets[job] = p;
     return p;
 }
