@@ -14,16 +14,15 @@
 #include <util/log.h>
 #include <util/logsystemmanager.h>
 
-K_PLUGIN_FACTORY_WITH_JSON(ktorrent_mediaplayer, "ktorrent_mediaplayer.json", registerPlugin<kt::MediaPlayerPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(kt::MediaPlayerPlugin, "ktorrent_mediaplayer.json")
 
 using namespace bt;
 
 namespace kt
 {
-MediaPlayerPlugin::MediaPlayerPlugin(QObject *parent, const QVariantList &args)
-    : Plugin(parent)
+MediaPlayerPlugin::MediaPlayerPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : Plugin(parent, data, args)
 {
-    Q_UNUSED(args);
 }
 
 MediaPlayerPlugin::~MediaPlayerPlugin()
@@ -51,11 +50,6 @@ void MediaPlayerPlugin::unload()
     act = nullptr;
 }
 
-bool MediaPlayerPlugin::versionCheck(const QString &version) const
-{
-    return version == QStringLiteral(VERSION);
-}
-
 }
 
 #include "mediaplayerplugin.moc"
