@@ -11,8 +11,6 @@
 #include <QLocale>
 #include <QPalette>
 
-#include <KRun>
-
 #include "feedwidget.h"
 #include "feedwidgetmodel.h"
 #include "filterlist.h"
@@ -51,7 +49,7 @@ FeedWidget::FeedWidget(FilterList *filters, SyndicationActivity *act, QWidget *p
     connect(m_download, &QPushButton::clicked, this, &FeedWidget::downloadClicked);
     connect(m_refresh, &QPushButton::clicked, this, &FeedWidget::refreshClicked);
     connect(m_filters, &QPushButton::clicked, this, &FeedWidget::filtersClicked);
-    connect(m_refresh_rate, qOverload<int>(&QSpinBox::valueChanged), this, &FeedWidget::refreshRateChanged);
+    connect(m_refresh_rate, &QSpinBox::valueChanged, this, &FeedWidget::refreshRateChanged);
     connect(m_cookies, &QPushButton::clicked, this, &FeedWidget::cookiesClicked);
 
     m_refresh->setIcon(QIcon::fromTheme(QStringLiteral("view-refresh")));
@@ -188,7 +186,7 @@ void FeedWidget::selectionChanged(const QItemSelection &sel, const QItemSelectio
         Syndication::ItemPtr item = model->itemForIndex(m_item_list->selectionModel()->selectedRows().front());
         if (item) {
             m_item_view->setHtml(item_template.arg(item->title())
-                                     .arg(QLocale().toString(QDateTime::fromTime_t(item->datePublished()), QLocale::ShortFormat))
+                                     .arg(QLocale().toString(QDateTime::fromSecsSinceEpoch(item->datePublished()), QLocale::ShortFormat))
                                      .arg(item->description())
                                      .arg(QApplication::palette().text().color().name(QColor::NameFormat::HexRgb)),
                                  QUrl(feed->feedData()->link()));
