@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2008 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <QMimeDatabase>
 #include <QMimeType>
@@ -88,7 +73,7 @@ void LinkDownloader::downloadFinished(KJob *j)
     }
 
     if (isTorrent(job->data())) {
-        bt::TorrentInterface *tc = 0;
+        bt::TorrentInterface *tc = nullptr;
         if (verbose)
             tc = core->load(job->data(), url, group, location);
         else
@@ -185,7 +170,7 @@ void LinkDownloader::tryNextLink()
     if (links.count() == 0) {
         Out(SYS_SYN | LOG_DEBUG) << "Couldn't find a valid link to a torrent on " << url.toDisplayString() << endl;
         if (verbose)
-            KMessageBox::error(0, i18n("Could not find a valid link to a torrent on %1", url.toDisplayString()));
+            KMessageBox::error(nullptr, i18n("Could not find a valid link to a torrent on %1", url.toDisplayString()));
 
         finished(false);
         deleteLater();
@@ -213,7 +198,7 @@ void LinkDownloader::torrentDownloadFinished(KJob *j)
         } else
             tryTorrentLinks();
     } else if (isTorrent(job->data())) {
-        bt::TorrentInterface *tc = 0;
+        bt::TorrentInterface *tc = nullptr;
         if (verbose)
             tc = core->load(job->data(), link_url, group, location);
         else
